# Installation

## With pip

You need the GNU Scientific Library and `cmake` on your system:

```{code-block} sh
sudo apt install libgsl-dev cmake
```

Then, assuming a recent version of `pip`:

```{code-block} sh
python3 -m pip install fwpdy11
```

## With conda

`fwpdy11` is available via [bioconda](http://bioconda.github.io/).
Please read their documentation, as channel order matters.

```{code-block} sh
conda install -c bioconda fwpdy11
```
